/****************************************************************************
 *
 * $Id:
 *
 * Copyright (C) 1998-2006 Lasmea. All rights reserved.
 *
 * This software was developed at:
 * Institut Pascal- UMR 6602
 * 63 175 Aubière Cedex
 * http://ip.univ-bpclermont.fr
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Trolltech AS of Norway and appearing in the file
 * LICENSE included in the packaging of this file.
 *
 * Licensees holding valid IPDS Professional Edition licenses may
 * use this file in accordance with the IPDS Commercial License
 * Agreement provided with the Software.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Contact . if any conditions of this licensing are
 * not clear to you.
 *
 *
 * Author: Jonathan Courbon - Hemanth Korrapati -
 *
 *****************************************************************************/


#include "config.h"
#include "unwrapper.h"

void usage()
{
    std::cout << "============================" << std::endl;
    std::cout << "  Omnidirectional image unwarping" << std::endl;
    std::cout << "============================" << std::endl;
    std::cout << "Usage: ./unwarpImage myimage.pgm " << std::endl;
}

int main(int argc, char* argv[])
{

    if(argc==2)
    {
        // Initialisation step
        unwrapper UW;       //Object creation
        UW.setCenter(658, 475);           //Center of the image
        UW.setInnerAndOuterRadius(84, 468);         //Inner and outer radius
        UW.setScale(.5, .5);       //Output image scale in x and y direction (1, 1) gives the unscaled image.
        UW.initialize();         // Initializes the object. Precomputes the mapping coordinates and uses for the subsequent images.


        // Unwarp the images
        cv::Mat inputImg,outputImg;
        inputImg = cv::imread(argv[1], CV_LOAD_IMAGE_COLOR);   // Read the file


        UW.unwrapImage(inputImg, outputImg, 2);
        inputImg.release();
        


        // save as png
        std::vector<int> compression_params;
        compression_params.push_back(CV_IMWRITE_PNG_COMPRESSION);
        compression_params.push_back(9);
        cv::imwrite("unwarpImage.png", outputImg, compression_params);
	
	outputImg.release();

    }
    else
    {
        usage();
    }

    return 0;



}
